@@ -211,7 +211,7 @@
   The CImg Library is an <i>open-source C++ toolkit for image processing</i>.\n
 
   It mainly consists in a (big) single header file
-  <a href="https://framagit.org/dtschump/CImg/raw/master/CImg.h">CImg.h</a>
+  <a href="https://github.com/dtschump/CImg/raw/master/CImg.h">CImg.h</a>
   providing a set of C++ classes and functions that can be used in your own sources,
   to load/save, manage/process and display generic images.
   It's actually a very simple and pleasant toolkit for coding image processing stuff in C++ :
@@ -223,10 +223,8 @@
   It is regularly tested on different architectures and compilers,
   and should also work on any decent OS having a decent C++ compiler.
   Before each release, the CImg Library is compiled under these different configurations :
-  \li PC Linux 32 bits, with g++.
-  \li PC Windows 32 bits, with Visual C++ Express Edition.
-  \li Sun SPARC Solaris 32 bits, with g++.
-  \li Mac PPC with OS X and g++.
+  \li PC Linux 32/64 bits, with g++.
+  \li PC Windows 32/64 bits, with Visual C++ Express Edition.
 
   CImg has a minimal number of dependencies. In its minimal version, it can be compiled only with standard C++ headers.
   Anyway, it has interesting extension capabilities and can use external libraries to perform specific tasks more
@@ -239,10 +237,10 @@
   The package is distributed under the <a href="http://www.cecill.info">CeCILL license</a>.
 
   This package contains :
-  - The main library file <a href="https://framagit.org/dtschump/CImg/raw/master/CImg.h">CImg.h</a> (C++ header file).
-  - Several C++ source code showing <a href="https://framagit.org/dtschump/CImg/tree/master/examples">examples of using CImg</a>.
+  - The main library file <a href="https://github.com/dtschump/CImg/raw/master/CImg.h">CImg.h</a> (C++ header file).
+  - Several C++ source code showing <a href="https://github.com/dtschump/CImg/tree/master/examples">examples of using CImg</a>.
   - A complete library documentation, in <a href="../CImg_reference.pdf">PDF</a> format.
-  - Additional <a href="https://framagit.org/dtschump/CImg/tree/master/plugins">library plug-ins</a> that can be used to extend
+  - Additional <a href="https://github.com/dtschump/CImg/tree/master/plugins">library plug-ins</a> that can be used to extend
   library capabilities for specific uses.
 
   The CImg Library is a quite lightweight library which is easy to maintain (due to its particular structure), and thus
@@ -268,10 +266,10 @@
   corresponding to different constraints on the source files :
   - The <a href="http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html">CeCILL-C</a> license is the most permissive one, close to
   the <i>GNU LGPL license</i>, and <i>applies <b>only</b> on the main library file
-  <a href="https://framagit.org/dtschump/CImg/raw/master/CImg.h">CImg.h</a></i>.
-  Basically, this license allows to use <a href="https://framagit.org/dtschump/CImg/raw/master/CImg.h">CImg.h</a>
+  <a href="https://github.com/dtschump/CImg/raw/master/CImg.h">CImg.h</a></i>.
+  Basically, this license allows to use <a href="https://github.com/dtschump/CImg/raw/master/CImg.h">CImg.h</a>
   in a closed-source product without forcing you to redistribute the entire software source code. Anyway,
-  if one modifies the <a href="https://framagit.org/dtschump/CImg/raw/master/CImg.h">CImg.h</a> source file, one has to redistribute
+  if one modifies the <a href="https://github.com/dtschump/CImg/raw/master/CImg.h">CImg.h</a> source file, one has to redistribute
   the modified version of the file that must be governed by the same <a href="http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html">CeCILL-C</a> license.
 
   - The <a href="http://www.cecill.info/licences/Licence_CeCILL_V2-en.html">CeCILL</a> license applies to all other files
@@ -316,7 +314,7 @@
   \subsection ssf23 2.3 Why is CImg entirely contained in a single header file ?
 
   People are often surprised to see that the complete code of the library is contained in a single (big) C++ header file
-  <a href="https://framagit.org/dtschump/CImg/raw/master/CImg.h">CImg.h</a>.
+  <a href="https://github.com/dtschump/CImg/raw/master/CImg.h">CImg.h</a>.
   There are good practical and technical reasons to do that. Some arguments are listed below to justify this approach,
   so (I hope) you won't think this is a awkwardly C++ design of the CImg library :\n
 
@@ -567,37 +565,6 @@
 **/
 /*@}*/
 
-/*-----------------------------------
-
-   Using drawing functions
-
-  -------------------------------------*/
-
-/** \addtogroup cimg_drawing Using Drawing Functions. */
-/*@{*/
-/**
-  \page foo5
-
-  \section s5 Using Drawing Functions.
-
-  This section tells more about drawing features in CImg images.
-  Drawing functions list can be found in <a href="structCImg.html">the CImg functions list</a>
-  (section \b Drawing Functions),
-  and are all defined on a common basis. Here are the important points to understand before using
-  drawing functions :
-
-  - Drawing is performed on the instance image. Drawing functions parameters
-  are defined as \e const variables and return a reference to the current instance <tt>(*this)</tt>,
-  so that drawing functions can be pipelined (see examples below).
-  Drawing is usually done in 2D color images but can be performed in 3D images with any vector-valued dimension,
-  and with any possible pixel type.
-
-  - A color parameter is always needed to draw features in an image. The color must be defined as a C-style array
-  whose dimension is at least
-
-**/
-/*@}*/
-
 /*-----------------------------------
 
    Using image loops
